scale_this: Scale a numeric vector without converting to a matrix
Description
This function scales and centres a numeric vector by subtracting the mean and dividing by the standard deviation.
Unlike `scale()`, it returns a numeric vector, not a matrix. Note this function does not allow control over centering or scaling.